@@ -17,6 +17,7 @@ import json
 import click
 from google.api_core import page_iterator
 from google.cloud import storage
+from google.cloud.exceptions import Conflict, NotFound
 
 from .base import BackendError, BaseBackend, validate_backend_empty
 
@@ -38,6 +39,28 @@ class GCSBackend(BaseBackend):
             if not self._gcs_prefix.endswith("/"):
                 self._gcs_prefix = f"{self._gcs_prefix}/"
 
+            if self._authenticator.creds_path:
+                self._storage_client = storage.Client.from_service_account_json(
+                    self._authenticator.creds_path
+                )
+            else:
+                self._storage_client = storage.Client(
+                    project=self._authenticator.project
+                )
+
+            try:
+                self._storage_client.get_bucket(self._gcs_bucket)
+            except NotFound:
+                if self._authenticator.create_backend_bucket:
+                    try:
+                        self._storage_client.create_bucket(self._gcs_bucket)
+                    except Conflict:
+                        pass
+                else:
+                    raise BackendError(
+                        "Backend bucket not found and --no-create-backend-bucket specified."
+                    )
+
     def _clean_deployment_limit(self, limit: tuple) -> None:
         """ only clean items within limit """
         full_state_list = self._get_state_list()
@@ -123,16 +146,6 @@ class GCSBackend(BaseBackend):
         if self._gcs_prefix is None or self._gcs_bucket is None:
             raise BackendError("clean attempted without proper authenticator setup")
 
-        if not hasattr(self, "_storage_client"):
-            if self._authenticator.creds_path:
-                self._storage_client = storage.Client.from_service_account_json(
-                    self._authenticator.creds_path
-                )
-            else:
-                self._storage_client = storage.Client(
-                    project=self._authenticator.project
-                )
-
         # clean entire deployment
         if not limit:
             self._clean_prefix(self._gcs_prefix)
