@@ -13,9 +13,12 @@
 # limitations under the License.
 
 import json
+import os
+import sys
 from contextlib import closing
 
 import boto3
+import botocore
 import click
 
 from .base import BackendError, BaseBackend, validate_backend_empty
@@ -55,6 +58,60 @@ class S3Backend(BaseBackend):
             )
             self._create_table(locking_table_name)
 
+        # Initialize s3 client and create bucket if necessary.
+        self._s3_client = self._authenticator.backend_session.client("s3")
+        try:
+            self._s3_client.head_bucket(Bucket=self._authenticator.bucket)
+        except botocore.exceptions.ClientError as err:
+            err_str = str(err)
+            if "Not Found" not in err_str:
+                raise err
+            if self._authenticator.create_backend_bucket:
+                try:
+                    self._s3_client.create_bucket(
+                        Bucket=self._authenticator.bucket,
+                        CreateBucketConfiguration={
+                            "LocationConstraint": self._authenticator.region
+                        },
+                        ACL="private",
+                    )
+                except botocore.exceptions.ClientError as err:
+                    err_str = str(err)
+                    if "InvalidLocationConstraint" in err_str:
+                        click.secho(
+                            "InvalidLocationConstraint raised when trying to create a bucket. "
+                            "Verify the AWS Region passed to the worker matches the AWS region "
+                            "in the profile.",
+                            fg="red",
+                        )
+                    elif "BucketAlreadyExists" in err_str:
+                        # Ignore when testing
+                        if "PYTEST_CURRENT_TEST" not in os.environ:
+                            click.secho(err_str, fg="red")
+                            sys.exit(4)
+                    elif "BucketAlreadyOwnedByYou" not in err_str:
+                        raise err
+
+                # Block public access
+                self._s3_client.put_public_access_block(
+                    Bucket=self._authenticator.bucket,
+                    PublicAccessBlockConfiguration={
+                        "BlockPublicAcls": True,
+                        "IgnorePublicAcls": True,
+                        "BlockPublicPolicy": True,
+                        "RestrictPublicBuckets": True,
+                    },
+                )
+
+                # Enable versioning on the bucket
+                s3_resource = self._authenticator.backend_session.resource("s3")
+                versioning = s3_resource.BucketVersioning(self._authenticator.bucket)
+                versioning.enable()
+            else:
+                raise BackendError(
+                    "Backend bucket not found and --no-create-backend-bucket specified."
+                )
+
     def _check_table_exists(self, name: str) -> bool:
         """ check if a supplied dynamodb table exists """
         if name in self._ddb_client.list_tables()["TableNames"]:
@@ -69,10 +126,7 @@ class S3Backend(BaseBackend):
         optionally definition can be passed to limit the cleanup
         to a single definition
         """
-        s3_paginator = self._authenticator.backend_session.client("s3").get_paginator(
-            "list_objects_v2"
-        )
-        s3_client = self._authenticator.backend_session.client("s3")
+        s3_paginator = self._s3_client.get_paginator("list_objects_v2")
 
         if definition is None:
             prefix = self._authenticator.prefix
@@ -82,7 +136,7 @@ class S3Backend(BaseBackend):
         for s3_object in self.filter_keys(
             s3_paginator, self._authenticator.bucket, prefix
         ):
-            backend_file = s3_client.get_object(
+            backend_file = self._s3_client.get_object(
                 Bucket=self._authenticator.bucket, Key=s3_object
             )
             body = backend_file["Body"]
@@ -149,8 +203,7 @@ class S3Backend(BaseBackend):
         note: in initial testing this isn't required, but is inconsistent with how S3 delete markers, and the boto
         delete object call work there may be some configurations that require extra handling.
         """
-        s3_client = self._authenticator.backend_session.client("s3")
-        s3_client.delete_object(Bucket=self._authenticator.bucket, Key=key)
+        self._s3_client.delete_object(Bucket=self._authenticator.bucket, Key=key)
 
     def clean(self, deployment: str, limit: tuple = None) -> None:
         """
