@@ -23,27 +23,23 @@ from collections import OrderedDict
 
 import click
 import jinja2
+import tfworker.util.hcl2_transformer as hcl2_transformer
 import yaml
+from hcl2.lark_parser import Lark_StandAlone
 from jinja2.runtime import StrictUndefined
 
 
 class RootCommand:
-    def __init__(self, args=None, clean=True):
+    def __init__(self, args={}, clean=True):
         """Setup state with args that are passed."""
         self.clean = clean
         self.temp_dir = tempfile.mkdtemp()
         self.args = self.StateArgs()
+        self.config_file = args.get("config_file")
 
         # Config accessors
         self.tf = None
-        self._pullup_keys()
-
-        if args is not None:
-            self.add_args(args)
-
-        if args.get("config_file") and args.get("backend"):
-            click.secho(f"loading config file {args.get('config_file')}", fg="green")
-            self.load_config(args.get("config_file"))
+        self.add_args(args)
 
     def __del__(self):
         """Cleanup the temporary directory after execution."""
@@ -63,26 +59,38 @@ class RootCommand:
         setattr(self.args, k, v)
         return None
 
-    def load_config(self, config_file):
+    def load_config(self):
+        if not self.config_file:
+            return
         try:
             template_reader = io.StringIO()
             jinja_env = jinja2.Environment(
                 undefined=StrictUndefined,
-                loader=jinja2.FileSystemLoader(pathlib.Path(config_file).parents[0]),
+                loader=jinja2.FileSystemLoader(
+                    pathlib.Path(self.config_file).parents[0]
+                ),
+            )
+            template_config = jinja_env.get_template(
+                pathlib.Path(self.config_file).name
             )
-            template_config = jinja_env.get_template(pathlib.Path(config_file).name)
             # maybe get_env should be optional?
             template_config.stream(
                 **self.args.template_items(return_as_dict=True, get_env=True)
             ).dump(template_reader)
-            self.config = ordered_config_load(template_reader.getvalue(), self.args)
+            if self.config_file.endswith(".hcl"):
+                self.config = ordered_config_load_hcl(
+                    template_reader.getvalue(), self.args
+                )
+            else:
+                self.config = ordered_config_load(template_reader.getvalue(), self.args)
 
             # A little arbitrary, but decorate the top two levels
             # directly on self object
             self.tf = self.config.get("terraform", OrderedDict())
             self._pullup_keys()
+            self._merge_args()
         except jinja2.exceptions.TemplateNotFound as e:
-            path = pathlib.Path(config_file).parents[0]
+            path = pathlib.Path(self.config_file).parents[0]
             click.secho(f"can not read template file: {path}/{e}", fg="red")
             raise SystemExit(1)
         except jinja2.exceptions.UndefinedError as e:
@@ -101,12 +109,17 @@ class RootCommand:
             "remote_vars",
             "template_vars",
             "terraform_vars",
+            "worker_options",
         ]:
             if self.tf:
                 setattr(self, f"{k}_odict", self.tf.get(k, OrderedDict()))
             else:
                 setattr(self, f"{k}_odict", None)
 
+    def _merge_args(self):
+        for k, v in self.worker_options_odict.items():
+            self.add_arg(k, v)
+
     class StateArgs:
         """A class to hold arguments in the state for easier access."""
 
@@ -116,6 +129,9 @@ class RootCommand:
         def __getitem__(self, name):
             return self.__dict__[name]
 
+        def __repr__(self):
+            return str(self.__dict__)
+
         def keys(self):
             return self.__dict__.keys()
 
@@ -163,6 +179,32 @@ def get_config_var_dict(config_vars):
     return return_vars
 
 
+def replace_hcl_vars(hcl, args):
+    if isinstance(hcl, dict):
+        for key in hcl.keys():
+            hcl[key] = replace_hcl_vars(hcl[key], args)
+    elif isinstance(hcl, list):
+        for i in range(len(hcl)):
+            hcl[i] = replace_hcl_vars(hcl[i], args)
+    elif isinstance(hcl, str):
+        return replace_vars(hcl, args)
+    return hcl
+
+
+def ordered_config_load_hcl(stream, args):
+    """
+    Load an hcl config, and replace templated items.
+
+    Derived from:
+    https://stackoverflow.com/questions/5121931/in-python-how-can-you-load-yaml-mappings-as-ordereddicts
+    """
+    hcl2_ordered = Lark_StandAlone(
+        transformer=hcl2_transformer.OrderedDictTransformer()
+    )
+    doc = hcl2_ordered.parse(stream + "\n")
+    return replace_hcl_vars(doc, args)
+
+
 def ordered_config_load(
     stream, args, Loader=yaml.SafeLoader, object_pairs_hook=OrderedDict
 ):
