@@ -16,13 +16,11 @@ import os
 
 _CWD = os.getcwd()
 
-DEFAULT_BACKEND_BUCKET = "tfworker-terraform-states"
+
 DEFAULT_BACKEND_PREFIX = "terraform/state/{deployment}"
 DEFAULT_CONFIG = f"{_CWD}/worker.yaml"
 DEFAULT_REPOSITORY_PATH = _CWD
-DEFAULT_AWS_REGION = "us-west-2"
-DEFAULT_GCP_REGION = "us-west2b"
-DEFAULT_BACKEND_REGION = "us-west-2"
-DEFAULT_TERRFORM = "/usr/local/bin/terraform"
+DEFAULT_AWS_REGION = "us-east-1"
+DEFAULT_GCP_REGION = "us-east-1a"
 
 RESERVED_FILES = ["terraform.tf", "worker-locals.tf", "worker.auto.tfvars"]
