@@ -24,22 +24,19 @@ from .helm import HelmProvider  # noqa
 
 ALL = [AWSProvider, GoogleProvider, GoogleBetaProvider, HelmProvider]
 
-REQUIRED_PROVIDERS_TPL = """\
-  required_providers {{
-{0}
-  }}"""
-
 
 class ProvidersCollection(collections.abc.Mapping):
-    def __init__(self, providers_odict, rootc):
+    def __init__(self, providers_odict, authenticators, tf_version_major):
         provider_map = dict([(prov.tag, prov) for prov in ALL])
         self._providers = copy.deepcopy(providers_odict)
         for k, v in self._providers.items():
             try:
-                self._providers[k] = provider_map[k](v, rootc)
+                self._providers[k] = provider_map[k](
+                    v, authenticators, tf_version_major
+                )
 
             except KeyError:
-                self._providers[k] = GenericProvider(v, tag=k)
+                self._providers[k] = GenericProvider(v, tf_version_major, tag=k)
 
     def __len__(self):
         return len(self._providers)
@@ -52,18 +49,10 @@ class ProvidersCollection(collections.abc.Mapping):
     def __iter__(self):
         return iter(self._providers.values())
 
-    @property
-    def has_required_providers(self):
-        return (
-            len([prov.required() for _, prov in self._providers.items() if prov.source])
-            > 0
-        )
+    def keys(self):
+        return self._providers.keys()
 
-    def hcl(self):
-        return "\n".join([prov.hcl() for _, prov in self._providers.items()])
-
-    def required_providers(self):
-        content = "\n".join(
-            [prov.required() for _, prov in self._providers.items() if prov.source]
+    def hcl(self, includes):
+        return "\n".join(
+            [prov.hcl() for k, prov in self._providers.items() if k in includes]
         )
-        return REQUIRED_PROVIDERS_TPL.format(content)
