@@ -16,17 +16,25 @@
 class BaseProvider:
     tag = None
 
-    def __init__(self, body):
+    def __init__(self, body, tf_version_major):
+        self._tf_version_major = tf_version_major
+
         self.vars = body.get("vars", {})
         self.version = self.vars.get("version")
         self.source = body.get("source")
 
+        self._field_filter = ["version"]
+
     def hcl(self):
         result = []
         provider_vars = {}
         try:
             for k, v in self.vars.items():
-                provider_vars[k] = v
+                if self._tf_version_major >= 13:
+                    if k not in self._field_filter:
+                        provider_vars[k] = v
+                else:
+                    provider_vars[k] = v
         except (KeyError, TypeError):
             """No provider vars were set."""
             pass
